import { PaginationModel } from "./PaginationModel";
export declare class ProductModel {
    AvantageId?: number | null;
    ProductCode: string;
    ProductType: ProductType;
    ProductId?: number;
    Enabled?: boolean;
    ProductVersion?: string;
    ProuductGroup?: ProuductGroup | null;
    ProductName: string;
    ShortDescription?: string | null;
    LongDescription?: string | null;
    Translations?: ProductTranslation[];
    AdditionalFields?: AdditionalField[];
    ProductCategory?: string;
    Discount?: number;
    DiscountType?: "PERCENT";
    PricingConfigurations: PriceConfiguration[];
    Prices?: any;
    BundleProducts?: any[];
    Fullfilment?: string;
    FullfilmentInformation?: FullfilmentInformation;
    GeneratesSubscription?: boolean;
    SubscriptionInformation?: SubscriptionInformation;
    ChangeOptionsQuantityAtManualRenewal?: boolean;
    PurchaseMultipleUnits?: boolean;
    Errors?: string[];
    constructor(data: ProductModel);
}
declare type ProductType = "REGULAR" | "BUNDLE";
interface ProuductGroup {
}
interface ProductTranslation extends ProductModel {
    Language: string;
}
export interface PriceConfiguration {
    Name?: string;
    Code?: string | null;
    Default?: boolean;
    BillingCountries?: any[];
    UseOriginalPrices?: boolean;
    PricingSchema: "DYNAMIC";
    PriceType?: "NET";
    DefaultCurrency?: string;
    Prices: {
        Regular: Price[];
        Renewal: Price[];
    };
}
interface Price {
    Amount: number;
    Currency: string;
    MinQuantity: number;
    MaxQuantity: number;
    OptionCodes: any[];
}
interface FullfilmentInformation {
    IsStartAfterFulfillment: boolean;
    IsElectronicCode: boolean;
    IsDownloadLink: boolean;
    IsBackupMedia: boolean;
    IsDownloadInsuranceService: boolean;
    IsInstantDeliveryThankYouPage: boolean;
    IsDisplayInPartnersCPanel: boolean;
    CodeList?: {
        Code?: string;
        Name?: string;
        Type?: string;
    };
    BackupMedia?: {
        Code?: string;
        Name?: string;
        Type?: string;
    };
    ProductFile?: {
        Code?: string;
        Name?: string;
        File?: string;
        Version?: string;
        Size?: string;
        Type?: string;
        LastUpdate?: string;
    };
    AdditionalInformationByEmail?: string;
    AdditionalInformationEmailTranslations?: [{
        Name?: string;
        Description?: string;
        Language?: string;
    }];
    AdditionalThankYouPage?: string;
    AdditionalThankYouPageTranslations?: [{
        Name?: string;
        Description?: string;
        Language?: string;
    }];
    ReturnMethod: {
        Type: string | null;
        URL: string | null;
    };
}
interface SubscriptionInformation {
    DeprecatedProducts?: [any];
    BundleRenewalManagement?: string;
    BillingCycle?: string;
    BillingCycleUnits?: string;
    IsOneTimeFee?: boolean;
    ContractPeriod?: {
        Action?: string;
        EmailsDuringContract?: boolean;
        Period?: number;
        PeriodUnits?: string;
        IsUnlimited?: boolean;
    };
    UsageBilling?: number;
    GracePeriod?: {
        Type?: string;
        PeriodUnits?: string;
        Period?: string;
        IsUnlimited?: boolean;
    };
    RenewalEmails?: {
        Type?: string;
        Settings?: {
            ManualRenewal?: {
                Before30Days?: boolean;
                Before15Days?: boolean;
                Before7Days?: boolean;
                Before1Day?: boolean;
                OnExpirationDate?: boolean;
                After5Days?: boolean;
                After15Days?: boolean;
            };
            AutomaticRenewal?: {
                Before30Days?: boolean;
                Before15Days?: boolean;
                Before7Days?: boolean;
                Before1Day?: boolean;
                OnExpirationDate?: boolean;
                After5Days?: boolean;
                After15Days?: boolean;
            };
        };
    };
}
interface AdditionalField {
    Code: string;
    Text: string;
    Value: string;
}
export declare class ProductsModel {
    Items: ProductModel[];
    Pagination: PaginationModel;
    constructor(data: ProductsModel);
}
export {};
