'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var crypto = require('crypto');
var dateFormatNs = require('dateformat');
var axios = _interopDefault(require('axios'));
var qs = require('qs');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

class PaginationModel {
  constructor(data) {
    this.Page = data.Page;
    this.Limit = data.Limit;
    this.Count = data.Count;
  }

}

class ProductModel {
  constructor(data) {
    Object.assign(this, data);
  }

}
class ProductsModel {
  constructor(data) {
    this.Items = data.Items.map(item => new ProductModel(item));
    this.Pagination = new PaginationModel(data.Pagination);
  }

}

class OrderModel {
  constructor(data) {
    Object.assign(this, data);
  }

}
class OrdersModel {
  constructor(data) {
    this.Items = data.Items.map(item => new OrderModel(item));
    this.Pagination = new PaginationModel(data.Pagination);
  }

}

class ProductsService {
  constructor(api) {
    this.api = api;
  }

  createProduct(product) {
    try {
      const _this = this;

      return Promise.resolve(_this.api.post("/products/", product)).then(function () {
        const created_order = new ProductModel(_extends({}, product));
        return created_order;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }

  deleteProduct(product_code) {
    try {
      const _this2 = this;

      return Promise.resolve(_this2.api.delete(`/products/${product_code}/`)).then(function () {});
    } catch (e) {
      return Promise.reject(e);
    }
  }

  getProducts() {
    try {
      const _this3 = this;

      return Promise.resolve(_this3.api.get("/products/")).then(function (data) {
        return new ProductsModel(data);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }

}

class OrdersService {
  constructor(api) {
    this.api = api;
  }

  createOrder(order) {
    try {
      const _this = this;

      return Promise.resolve(_this.api.post("/orders/", order)).then(function (data) {
        const created_order = new OrderModel(data);
        return created_order;
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }

  getOrders() {
    try {
      const _this2 = this;

      return Promise.resolve(_this2.api.get("/orders/")).then(function (data) {
        return new OrdersModel(data);
      });
    } catch (e) {
      return Promise.reject(e);
    }
  }

}

const dateFormat = dateFormatNs;
class HashCreator {
  constructor(merchant_id, secret_key, date = new Date()) {
    this.merchant_id = merchant_id;
    this.secret_key = secret_key;
    this.date = date;
    this.date_str = dateFormat(this.date, "UTC:yyyy-mm-dd hh:MM:ss");
  }

  _getString() {
    return `${this.merchant_id.length}${this.merchant_id}${this.date_str.length}${this.date_str}`;
  }

  _getHash() {
    const hasher = crypto.createHmac("md5", this.secret_key);
    hasher.update(this._getString());
    return hasher.digest("hex").toString();
  }

  getAuthString() {
    return `code="${this.merchant_id}" date="${this.date_str}" hash="${this._getHash()}"`;
  }

}

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

const TWOCHEKCOUT_BASE_URL = "https://api.2checkout.com/rest/6.0/";
const TWOCHEKCOUT_BUY_LINK_URL = "https://secure.2checkout.com/checkout/buy/";

class ApiResponseError extends Error {
  constructor(msg, response, status) {
    super(msg);
    this.response = response;
    this.status = status;
  }

}

const createApiResponseError = error => {
  if (error && error.response) {
    return new ApiResponseError(error.response.data.message, error.response, error.response.status);
  }

  return new ApiResponseError(error.message, null, 0);
};

class Api {
  constructor(merchant_id, service_key) {
    this.merchant_id = merchant_id;
    this.service_key = service_key;
    this.ax = axios.create({
      baseURL: TWOCHEKCOUT_BASE_URL,
      headers: {
        "Content-Type": "application/json"
      }
    });
  }

  get(endpoint_path) {
    try {
      const _this = this;

      const hc = new HashCreator(_this.merchant_id, _this.service_key);
      return Promise.resolve(_catch(function () {
        return Promise.resolve(_this.ax.get(endpoint_path, {
          headers: {
            "X-Avangate-Authentication": hc.getAuthString()
          }
        })).then(function (response) {
          return response.data;
        });
      }, function (error) {
        throw createApiResponseError(error);
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }

  post(endpoint_path, data) {
    try {
      const _this2 = this;

      const hc = new HashCreator(_this2.merchant_id, _this2.service_key);
      return Promise.resolve(_catch(function () {
        return Promise.resolve(_this2.ax.post(endpoint_path, data, {
          headers: {
            "X-Avangate-Authentication": hc.getAuthString()
          }
        })).then(function (response) {
          return response.data;
        });
      }, function (error) {
        throw createApiResponseError(error);
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }

  delete(endpoint_path) {
    try {
      const _this3 = this;

      const hc = new HashCreator(_this3.merchant_id, _this3.service_key);
      return Promise.resolve(_catch(function () {
        return Promise.resolve(_this3.ax.delete(endpoint_path, {
          headers: {
            "X-Avangate-Authentication": hc.getAuthString()
          }
        })).then(function (response) {
          return response.data;
        });
      }, function (error) {
        throw createApiResponseError(error);
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  }

}

const REQUIRED_FOR_SIGNATURE = ["return-url", "return-type", "expiration", "order-ext-ref", "item-ext-ref", "customer-ref", "customer-ext-ref"];
const REQUIRED_FOR_DYNAMIC = ["currency", "prod", "price", "qty", "tangible", "type", "opt", "description", "recurrence", "duration", "renewal-price"];

class BaseConvertPlusUrlGenerator {}

const getKeyOfFirstTruthyValue = value => {
  return Object.keys(value).find(key => value[key]);
};

const translateBooleanValue = value => {
  if (value === undefined) return value;
  return value ? "1" : "0";
};

class ConvertPlusUrlGenerator extends BaseConvertPlusUrlGenerator {
  constructor(merchant, secret_word, data) {
    super();
    this.merchant = merchant;
    this.secret_word = secret_word;
    Object.assign(this, data); // this.check();
  }

  getUrl() {
    return `${TWOCHEKCOUT_BUY_LINK_URL}?${qs.stringify(this.getParameters())}`;
  }
  /**
   * Get parameters for url in right form
   */


  getParameters() {
    let params = {
      email: this.email,
      name: this.name,
      phone: this.phone,
      country: this.country,
      state: this.state,
      address: this.address,
      address2: this.address2,
      zip: this.zip,
      "ship-name": this.shipName,
      "ship-country": this.shipCountry,
      "ship-state": this.shipState,
      "ship-address": this.shipAddress,
      "ship-address2": this.shipAddress2,
      "ship-zip": this.shipZip,
      dynamic: translateBooleanValue(this.dynamic),
      prod: this.prod.join(";"),
      "item-ext-ref": this.itemExtRef,
      type: this.type,
      qty: this.qty.join(";"),
      price: this.getPrice(),
      tangible: translateBooleanValue(this.tangible),
      opt: this.opt,
      description: this.description,
      recurrence: this.getRecurrence(),
      duration: this.duration,
      "renewal-price": this.renewalPrice,
      merchant: this.merchant,
      subscription: this.subscription,
      expiration: this.expiration,
      "return-url": this.returnUrl,
      "return-type": this.returnType,
      coupon: this.coupon ? this.coupon.join(";") : undefined,
      src: this.src,
      tpl: this.tpl,
      currency: this.currency,
      "empty-cart": translateBooleanValue(this.emptyCart),
      "order-ext-ref": this.orderExtRef,
      language: this.language,
      "origin-url": this.originUrl,
      style: this.style,
      test: translateBooleanValue(this.test),
      "customer-ref": this.customerRef,
      "customer-ext-ref": this.customerExtRef,
      lock: translateBooleanValue(this.lock)
    }; // filter parameters with undefined

    params = Object.keys(params).reduce((acc, key) => {
      if (params[key] !== undefined) {
        acc[key] = params[key];
      }

      return acc;
    }, {});
    return _extends({}, params, {
      signature: this.getSignature(params)
    });
  }

  getPrice() {
    return this.price ? this.price.map(v => {
      if (typeof v === "object") {
        const first_key = Object.keys(v)[0];
        return `${first_key}:${v[first_key]}`;
      } else {
        return v.toString();
      }
    }).join(";") : undefined;
  }

  getRecurrence() {
    return this.recurrence ? this.recurrence.map(obj => {
      const k = getKeyOfFirstTruthyValue(obj);

      if (k === undefined) {
        return undefined;
      }

      return `${k}:${obj[k]}`;
    }).filter(v => v).join(";") : undefined;
  }

  getSignature(parameters) {
    const fields = [...REQUIRED_FOR_SIGNATURE, ...(this.dynamic ? REQUIRED_FOR_DYNAMIC : [])];
    const keys = Object.keys(parameters).filter(key => fields.includes(key) && parameters.hasOwnProperty(key)).sort();
    const str = keys.reduce((acc, cur) => {
      return `${acc}${parameters[cur].length}${parameters[cur]}`;
    }, "");
    const hasher = crypto.createHmac("sha256", this.secret_word);
    hasher.update(str);
    return hasher.digest("hex").toString();
  }

}

class Twocheckout {
  constructor(merchant_id, service_key) {
    this.merchant_id = merchant_id;
    this.service_key = service_key;
    this.api = new Api(merchant_id, service_key);
    this.productsService = new ProductsService(this.api);
    this.ordersService = new OrdersService(this.api);
  }

}

exports.ConvertPlusUrlGenerator = ConvertPlusUrlGenerator;
exports.Twocheckout = Twocheckout;
exports.default = Twocheckout;
//# sourceMappingURL=ya2checkout.cjs.development.js.map
